@@ -59,7 +59,6 @@ FS.staticInit();
 #if FS_DEBUG
     trackingDelegate: {},
 #endif
-    ErrnoError: null, // set during init
     filesystems: null,
     syncFSRequests: 0, // we warn if there are multiple in flight at once
 #if expectToReceiveOnModule('logReadFiles')
@@ -1626,7 +1625,7 @@ FS.staticInit();
         try {
           FS.mkdir(current);
         } catch (e) {
-          // ignore EEXIST
+          if (e.errno != {{{ cDefs.EEXIST }}}) throw e;
         }
         parent = current;
       }
