@@ -25,10 +25,34 @@
 
 {{{
 #if MEMORY64
-globalThis.MAX_PTR = Number((2n ** 64n) - 1n);
+const MAX_PTR = Number((2n ** 64n) - 1n);
 #else
-globalThis.MAX_PTR = (2 ** 32) - 1
+const MAX_PTR = (2 ** 32) - 1
 #endif
+// Use a macro to avoid duplicating pthread worker options.
+// We cannot use a normal JS variable since the vite bundler requires that worker
+// options be inline.
+// See https://github.com/emscripten-core/emscripten/issues/22394
+const pthreadWorkerOptions = `{
+#if EXPORT_ES6
+        'type': 'module',
+#endif
+#if ENVIRONMENT_MAY_BE_NODE
+        // This is the way that we signal to the node worker that it is hosting
+        // a pthread.
+        'workerData': 'em-pthread',
+#endif
+#if ENVIRONMENT_MAY_BE_WEB || ENVIRONMENT_MAY_BE_WORKER
+        // This is the way that we signal to the Web Worker that it is hosting
+        // a pthread.
+#if ASSERTIONS
+        'name': 'em-pthread-' + PThread.nextWorkerID,
+#else
+        'name': 'em-pthread',
+#endif
+#endif
+}`;
+null
 }}}
 
 var LibraryPThread = {
@@ -203,8 +227,8 @@ var LibraryPThread = {
       // linear memory.
       __emscripten_thread_free_data(pthread_ptr);
     },
-    receiveObjectTransfer(data) {
 #if OFFSCREENCANVAS_SUPPORT
+    receiveOffscreenCanvases(data) {
       if (typeof GL != 'undefined') {
         Object.assign(GL.offscreenCanvases, data.offscreenCanvases);
         if (!Module['canvas'] && data.moduleCanvasId && GL.offscreenCanvases[data.moduleCanvasId]) {
@@ -212,8 +236,8 @@ var LibraryPThread = {
           Module['canvas'].id = data.moduleCanvasId;
         }
       }
-#endif
     },
+#endif
     // Called by worker.js each time a thread is started.
     threadInitTLS() {
 #if PTHREADS_DEBUG
@@ -394,26 +418,7 @@ var LibraryPThread = {
     // Creates a new web Worker and places it in the unused worker pool to wait for its use.
     allocateUnusedWorker() {
       var worker;
-      var workerOptions = {
 #if EXPORT_ES6
-        'type': 'module',
-#endif
-#if ENVIRONMENT_MAY_BE_NODE
-        // This is the way that we signal to the node worker that it is hosting
-        // a pthread.
-        'workerData': 'em-pthread',
-#endif
-#if ENVIRONMENT_MAY_BE_WEB || ENVIRONMENT_MAY_BE_WORKER
-        // This is the way that we signal to the Web Worker that it is hosting
-        // a pthread.
-#if ASSERTIONS
-        'name': 'em-pthread-' + PThread.nextWorkerID,
-#else
-        'name': 'em-pthread',
-#endif
-#endif
-      };
-#if EXPORT_ES6 && USE_ES6_IMPORT_META
       // If we're using module output, use bundler-friendly pattern.
 #if PTHREADS_DEBUG
       dbg(`Allocating a new web worker from ${import.meta.url}`);
@@ -427,15 +432,15 @@ var LibraryPThread = {
             createScriptURL: (ignored) => new URL("{{{ TARGET_JS_NAME }}}", import.meta.url)
           }
         );
-        worker = new Worker(p.createScriptURL('ignored'), workerOptions);
+        worker = new Worker(p.createScriptURL('ignored'), {{{ pthreadWorkerOptions }}});
       } else
 #endif
       // We need to generate the URL with import.meta.url as the base URL of the JS file
       // instead of just using new URL(import.meta.url) because bundler's only recognize
       // the first case in their bundling step. The latter ends up producing an invalid
       // URL to import from the server (e.g., for webpack the file:// path).
-      worker = new Worker(new URL('{{{ TARGET_JS_NAME }}}', import.meta.url), workerOptions);
-#else
+      worker = new Worker(new URL('{{{ TARGET_JS_NAME }}}', import.meta.url), {{{ pthreadWorkerOptions }}});
+#else // EXPORT_ES6
       var pthreadMainJs = _scriptName;
 #if expectToReceiveOnModule('mainScriptUrlOrBlob')
       // We can't use makeModuleReceiveWithVar here since we want to also
@@ -454,11 +459,11 @@ var LibraryPThread = {
       // Use Trusted Types compatible wrappers.
       if (typeof trustedTypes != 'undefined' && trustedTypes.createPolicy) {
         var p = trustedTypes.createPolicy('emscripten#workerPolicy2', { createScriptURL: (ignored) => pthreadMainJs });
-        worker = new Worker(p.createScriptURL('ignored'), workerOptions);
+        worker = new Worker(p.createScriptURL('ignored'), {{{ pthreadWorkerOptions }}});
       } else
 #endif
-      worker = new Worker(pthreadMainJs, workerOptions);
-#endif // EXPORT_ES6 && USE_ES6_IMPORT_META
+      worker = new Worker(pthreadMainJs, {{{ pthreadWorkerOptions }}});
+#endif // EXPORT_ES6
       PThread.unusedWorkers.push(worker);
     },
 
