@@ -21,9 +21,6 @@ addToLibrary({
   $wasmFSDevices: {},
   $wasmFSDeviceStreams: {},
 
-  $FS__postset: `
-FS.init();
-`,
   $FS__deps: [
     '$MEMFS',
     '$wasmFSPreloadedFiles',
@@ -74,10 +71,14 @@ FS.init();
 #endif
   ],
   $FS : {
-    init() {
-      FS.ensureErrnoError();
+    ErrnoError: class extends Error {
+      name = 'ErrnoError';
+      message = 'FS error';
+      constructor(code) {
+        super();
+        this.errno = code
+      }
     },
-    ErrnoError: null,
     handleError(returnValue) {
       // Assume errors correspond to negative returnValues
       // since some functions like _wasmfs_open() return positive
@@ -88,16 +89,6 @@ FS.init();
 
       return returnValue;
     },
-    ensureErrnoError() {
-      if (FS.ErrnoError) return;
-      FS.ErrnoError = /** @this{Object} */ function ErrnoError(code) {
-        this.errno = code;
-        this.message = 'FS error';
-        this.name = "ErrnoError";
-      }
-      FS.ErrnoError.prototype = new Error();
-      FS.ErrnoError.prototype.constructor = FS.ErrnoError;
-    },
     createDataFile(parent, name, fileData, canRead, canWrite, canOwn) {
       FS_createDataFile(parent, name, fileData, canRead, canWrite, canOwn);
     },
@@ -111,7 +102,11 @@ FS.init();
         if (!wasmFSPreloadingFlushed) {
           wasmFSPreloadedDirs.push({parentPath: parent, childName: part});
         } else {
-          FS.mkdir(current);
+          try {
+            FS.mkdir(current);
+          } catch (e) {
+            if (e.errno != {{{ cDefs.EEXIST }}}) throw e;
+          }
         }
         parent = current;
       }
